@@ -1,21 +1,21 @@
 /*
-mediastreamer2 library - modular sound and video processing and streaming
-Copyright (C) 2006  Simon MORLAT (simon.morlat@linphone.org)
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of mediastreamer2.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifndef allfilters_h
 #define allfilters_h
@@ -103,6 +103,7 @@ typedef enum MSFilterId{
 	MS_ANDROID_SOUND_READ_ID,
 	MS_ANDROID_SOUND_WRITE_ID,
 	MS_JPEG_WRITER_ID,
+	MS_QRCODE_READER_ID,
 	MS_X11VIDEO_ID,
 	MS_ANDROID_DISPLAY_ID,
 	MS_ANDROID_VIDEO_READ_ID,
@@ -159,7 +160,19 @@ typedef enum MSFilterId{
 	MS_BV16_ENC_ID,
 	MS_UDP_SEND_ID,
 	MS_PCAP_FILE_PLAYER_ID,
-	MS_OGL_ID
+	MS_OGL_ID,
+	MS_G729_DEC_ID,
+	MS_G729_ENC_ID,
+	MS_WASAPI_READ_ID,
+	MS_WASAPI_WRITE_ID,
+	MS_AUDIO_FLOW_CONTROL_ID,
+	MS_MEDIACODEC_H265_DEC_ID,
+	MS_MEDIACODEC_H265_ENC_ID,
+	MS_VT_H265_DEC_ID,
+	MS_VT_H265_ENC_ID,
+	MS_ANDROID_DISPLAY_BAD_ID,
+	MS_ANDROID_OPENGL_DISPLAY_ID,
+	MS_ANDROID_TEXTURE_DISPLAY_ID
 } MSFilterId;
 
 #endif
